[xiph-commits] r8469 - trunk/oggdsf/src/lib/core/ogg/libOOOgg

illiminable at motherfish-iii.xiph.org illiminable at motherfish-iii.xiph.org
Thu Dec 16 09:32:35 PST 2004


Author: illiminable
Date: 2004-12-16 09:32:35 -0800 (Thu, 16 Dec 2004)
New Revision: 8469

Modified:
   trunk/oggdsf/src/lib/core/ogg/libOOOgg/OggPageInterleaver.cpp
Log:
* Page interleaver should now try notto put data berfore headers...

Modified: trunk/oggdsf/src/lib/core/ogg/libOOOgg/OggPageInterleaver.cpp
===================================================================
--- trunk/oggdsf/src/lib/core/ogg/libOOOgg/OggPageInterleaver.cpp	2004-12-16 17:31:24 UTC (rev 8468)
+++ trunk/oggdsf/src/lib/core/ogg/libOOOgg/OggPageInterleaver.cpp	2004-12-16 17:32:35 UTC (rev 8469)
@@ -130,14 +130,16 @@
 					//debugLog<<"writeLowest UNSCAL : Curr = "<<locCurrLowTimeUNS<<" -- Test["<<i<<"] = "<<locTestLowTimeUNS<<endl;
 
 					
 					//In english this means... any bos pages go first... then any no gran pos pages (-1 gran pos).. then
 					// whoevers got the lowest time.
 					if (
 						(	(mInputStreams[i]->peekFront() != NULL) && 
 							(mInputStreams[i]->peekFront()->header()->isBOS()) ) ||
 						
 						(	(mInputStreams[i]->peekFront() != NULL) && 
 							((mInputStreams[i]->peekFront()->header()->GranulePos()) == -1) ) ||
+							
+							(	(mInputStreams[i]->sentAllHeaders()) ) ||
 						
 							(locTestLowTime < locCurrLowTime)
 						) 
@@ -130,14 +130,16 @@
 
 					
-					//In english this means... any bos pages go first... then any no gran pos pages (-1 gran pos).. then
-					// whoevers got the lowest time.
+					//In english this means... any bos pages go first... then any no gran pos pages (-1 gran pos).. 
+					// then any remaining streams with headers then whoevers got the lowest time.
 					if (
 						(	(mInputStreams[i]->peekFront() != NULL) && 



More information about the commits mailing list